@@ -1,3 +1,4 @@
+#include <QtEndian>
 #include <QFile>
 #include <QRegularExpression>
 #include "common/util.h"
@@ -5,13 +6,6 @@
 
 using namespace ENC;
 
-#define UINT16(x) \
-  (((quint16)*(const uchar*)(x)) \
-  | ((quint16)(*((const uchar*)(x) + 1)) << 8))
-
-#define INT32(x) ((qint32)UINT32(x))
-#define INT16(x) ((qint16)UINT16(x))
-
 struct DR {
 	char RecordLength[5];
 	char InterchangeLevel;
@@ -29,18 +23,18 @@ struct DR {
 };
 
 
-const QVariant *ISO8211::Field::data(const QByteArray &name, int idx) const
+const QVariant *ISO8211::Field::data(quint32 name, int idx) const
 {
 	const QVector<QVariant> &v = _data.at(idx);
 
-	for (int i = 0; i < _subFields.size(); i++)
-		if (_subFields.at(i) == name)
+	for (int i = 0; i < _subFields->size(); i++)
+		if (_subFields->at(i) == name)
 			return &v.at(i);
 
 	return 0;
 }
 
-bool ISO8211::Field::subfield(const char *name, int *val, int idx) const
+bool ISO8211::Field::subfield(quint32 name, int *val, int idx) const
 {
 	bool ok;
 
@@ -52,7 +46,7 @@ bool ISO8211::Field::subfield(const char *name, int *val, int idx) const
 	return ok;
 }
 
-bool ISO8211::Field::subfield(const char *name, uint *val, int idx) const
+bool ISO8211::Field::subfield(quint32 name, uint *val, int idx) const
 {
 	bool ok;
 
@@ -64,7 +58,7 @@ bool ISO8211::Field::subfield(const char *name, uint *val, int idx) const
 	return ok;
 }
 
-bool ISO8211::Field::subfield(const char *name, QByteArray *val, int idx) const
+bool ISO8211::Field::subfield(quint32 name, QByteArray *val, int idx) const
 {
 	const QVariant *v = data(name, idx);
 	if (!v)
@@ -101,6 +95,7 @@ int ISO8211::readDR(QVector<FieldDefinition> &fields)
 	DR ddr;
 	QByteArray fieldLen, fieldPos;
 	int len, lenSize, posSize, tagSize, offset;
+	char tag[4];
 
 	static_assert(sizeof(ddr) == 24, "Invalid DR alignment");
 	if (_file.read((char*)&ddr, sizeof(ddr)) != sizeof(ddr))
@@ -115,20 +110,19 @@ int ISO8211::readDR(QVector<FieldDefinition> &fields)
 	if (len < 0 || offset < 0 || lenSize < 0 || posSize < 0 || tagSize < 0)
 		return -1;
 
-	fields.resize((offset - 1 - sizeof(DR)) / (lenSize + posSize + tagSize));
+	fields.resize((offset - 1 - sizeof(ddr)) / (lenSize + posSize + tagSize));
 	fieldLen.resize(lenSize);
 	fieldPos.resize(posSize);
 
 	for (int i = 0; i < fields.size(); i++) {
 		FieldDefinition &r = fields[i];
 
-		r.tag.resize(tagSize);
-
-		if (_file.read(r.tag.data(), tagSize) != tagSize
+		if (_file.read(tag, sizeof(tag)) != tagSize
 		  || _file.read(fieldLen.data(), lenSize) != lenSize
 		  || _file.read(fieldPos.data(), posSize) != posSize)
 			return -1;
 
+		r.tag = qFromLittleEndian<quint32>(tag);
 		r.pos = offset + Util::str2int(fieldPos.constData(), posSize);
 		r.size = Util::str2int(fieldLen.constData(), lenSize);
 
@@ -141,11 +135,12 @@ int ISO8211::readDR(QVector<FieldDefinition> &fields)
 
 bool ISO8211::readDDA(const FieldDefinition &def, SubFields &fields)
 {
-	static const QRegularExpression re("(\\d*)(\\w+)\\(*(\\d*)\\)*");
+	static const QRegularExpression re(
+	  "([0-9]*)(A|I|R|B|b11|b12|b14|b21|b22|b24)\\(*([0-9]*)\\)*");
 	QByteArray ba(def.size, Qt::Initialization::Uninitialized);
 	bool repeat = false;
 	QVector<SubFieldDefinition> defs;
-	QVector<QByteArray> defTags;
+	QVector<quint32> defTags;
 
 	if (!(_file.seek(def.pos) && _file.read(ba.data(), ba.size()) == ba.size()))
 		return false;
@@ -155,9 +150,9 @@ bool ISO8211::readDDA(const FieldDefinition &def, SubFields &fields)
 		repeat = true;
 		list[1].remove(0, 1);
 	}
-	QList<QByteArray> tags(list.at(1).split('!'));
 
 	if (list.size() > 2) {
+		QList<QByteArray> tags(list.at(1).split('!'));
 		QRegularExpressionMatchIterator it = re.globalMatch(list.at(2));
 		int tag = 0;
 
@@ -187,11 +182,17 @@ bool ISO8211::readDDA(const FieldDefinition &def, SubFields &fields)
 				SubFieldDefinition sfd(fieldType(typeStr, size));
 				if (sfd.type() == Unknown)
 					return false;
+				if (tag >= tags.size())
+					return false;
 				defs[tag] = sfd;
-				defTags[tag] = tags.at(tag);
+				defTags[tag] = (tags.at(tag).length() == 4)
+				  ? qFromLittleEndian<quint32>(tags.at(tag).constData()) : 0;
 				tag++;
 			}
 		}
+
+		if (tag != tags.size())
+			return false;
 	}
 
 	fields = SubFields(defTags, defs, repeat);
@@ -217,8 +218,10 @@ bool ISO8211::readDDR()
 	for (int i = 0; i < fields.size(); i++) {
 		SubFields def;
 		if (!readDDA(fields.at(i), def)) {
+			QByteArray tag(sizeof(quint32), Qt::Initialization::Uninitialized);
+			qToLittleEndian<quint32>(fields.at(i).tag, tag.data());
 			_errorString = QString("Error reading %1 DDA field")
-			  .arg(QString(fields.at(i).tag));
+			  .arg(QString(tag));
 			return false;
 		}
 		_map.insert(fields.at(i).tag, def);
@@ -270,11 +273,11 @@ bool ISO8211::readUDA(quint64 pos, const FieldDefinition &def,
 					dp++;
 					break;
 				case S16:
-					row[i] = QVariant(INT16(dp));
+					row[i] = QVariant(qFromLittleEndian<qint16>(dp));
 					dp += 2;
 					break;
 				case S32:
-					row[i] = QVariant(INT32(dp));
+					row[i] = QVariant(qFromLittleEndian<qint32>(dp));
 					dp += 4;
 					break;
 				case U8:
@@ -282,11 +285,11 @@ bool ISO8211::readUDA(quint64 pos, const FieldDefinition &def,
 					dp++;
 					break;
 				case U16:
-					row[i] = QVariant(UINT16(dp));
+					row[i] = QVariant(qFromLittleEndian<quint16>(dp));
 					dp += 2;
 					break;
 				case U32:
-					row[i] = QVariant(UINT32(dp));
+					row[i] = QVariant(qFromLittleEndian<quint32>(dp));
 					dp += 4;
 					break;
 				default:
@@ -322,13 +325,16 @@ bool ISO8211::readRecord(Record &record)
 
 		FieldsMap::const_iterator it(_map.find(def.tag));
 		if (it == _map.constEnd()) {
-			_errorString = QString("%1: unknown record").arg(QString(def.tag));
+			QByteArray tag(sizeof(quint32), Qt::Initialization::Uninitialized);
+			qToLittleEndian<quint32>(def.tag, tag.data());
+			_errorString = QString("%1: unknown record").arg(QString(tag));
 			return false;
 		}
 
 		if (!readUDA(pos, def, it->defs(), it->repeat(), data)) {
-			_errorString = QString("Error reading %1 record")
-			  .arg(QString(def.tag));
+			QByteArray tag(sizeof(quint32), Qt::Initialization::Uninitialized);
+			qToLittleEndian<quint32>(def.tag, tag.data());
+			_errorString = QString("Error reading %1 record").arg(QString(tag));
 			return false;
 		}
 
@@ -338,8 +344,7 @@ bool ISO8211::readRecord(Record &record)
 	return true;
 }
 
-
-const ISO8211::Field *ISO8211::field(const Record &record, const QByteArray &name)
+const ISO8211::Field *ISO8211::field(const Record &record, quint32 name)
 {
 	for (int i = 0; i < record.size(); i++)
 		if (record.at(i).tag() == name)
