@@ -19,6 +19,7 @@ using namespace IMG;
 #define TEXT_EXTENT 160
 #define ICON_PADDING 2
 #define RANGE_FACTOR 4
+#define MAJOR_RANGE  10
 #define ROAD  0
 #define WATER 1
 
@@ -228,64 +229,82 @@ void RasterTile::drawTextItems(QPainter *painter,
 
 static QRect lightRect(const QPoint &pos, quint32 range)
 {
-	return QRect(pos.x() - range * RANGE_FACTOR, pos.y() - range * RANGE_FACTOR,
-		  2*range * RANGE_FACTOR, 2*range * RANGE_FACTOR);
+	quint32 r = qMin(range * RANGE_FACTOR, (quint32)TEXT_EXTENT);
+	return QRect(pos.x() - r, pos.y() - r, 2 * r, 2 * r);
 }
 
 void RasterTile::drawSectorLights(QPainter *painter,
-  const QList<const MapData::Point *> &lights) const
+  const QList<const MapData::Point*> &lights) const
 {
 	for (int i = 0; i < lights.size(); i++) {
 		const MapData::Point *p = lights.at(i);
 		QPoint pos(p->coordinates.lon(), p->coordinates.lat());
+		QMap<Sector, quint32> rangeMap;
 
-		if (p->lights.sectors.size()) {
-			for (int j = 0; j < p->lights.sectors.size(); j++) {
-				const Lights::Sector &start = p->lights.sectors.at(j);
-				const Lights::Sector &end = (j == p->lights.sectors.size() - 1)
-				  ? p->lights.sectors.at(0) : p->lights.sectors.at(j+1);
+		for (int j = 0; j < p->lights.size(); j++) {
+			const Light &l = p->lights.at(j);
 
-				if (start.color) {
-					double a1 = -(end.angle / 10.0 + 90.0);
-					double a2 = -(start.angle / 10.0 + 90.0);
-					if (a1 > a2)
-						a2 += 360;
-					double as = (a2 - a1);
-					if (as == 0)
-						as = 360;
+			if (l.sectors().size()) {
+				for (int k = 0; k < l.sectors().size(); k++) {
+					const Light::Sector &start = l.sectors().at(k);
+					const Light::Sector &end = (k == l.sectors().size() - 1)
+					  ? l.sectors().at(0) : l.sectors().at(k+1);
+					quint32 angle = end.angle() - start.angle();
 
-					QRect rect(lightRect(pos, start.range ? start.range : 6));
+					if (start.color() && (angle || start.range() >= MAJOR_RANGE)) {
+						quint32 range = start.range() ? start.range() : 6;
+						Sector s(start.color(), start.angle(), end.angle());
+						if (rangeMap.value(s) >= range)
+							continue;
+						else
+							rangeMap.insert(s, range);
 
-					painter->setPen(QPen(Qt::black, 6, Qt::SolidLine,
-					  Qt::FlatCap));
-					painter->drawArc(rect, a1 * 16, as * 16);
-					painter->setPen(QPen(Style::color(start.color), 4,
-					  Qt::SolidLine, Qt::FlatCap));
-					painter->drawArc(rect, a1 * 16, as * 16);
+						double a1 = -(end.angle() / 10.0 + 90.0);
+						double a2 = -(start.angle() / 10.0 + 90.0);
+						if (a1 > a2)
+							a2 += 360;
+						double as = (a2 - a1);
+						if (as == 0)
+							as = 360;
 
-					if (a2 - a1 != 0) {
-						QLineF ln(pos, QPointF(pos.x() + rect.width(), pos.y()));
-						ln.setAngle(a1);
-						painter->setPen(QPen(Qt::black, 1, Qt::DashLine));
-						painter->drawLine(ln);
-						ln.setAngle(a2);
-						painter->drawLine(ln);
+						QRect rect(lightRect(pos, range));
+						painter->setPen(QPen(Qt::black, 6, Qt::SolidLine,
+						  Qt::FlatCap));
+						painter->drawArc(rect, a1 * 16, as * 16);
+						painter->setPen(QPen(Style::color(start.color()), 4,
+						  Qt::SolidLine, Qt::FlatCap));
+						painter->drawArc(rect, a1 * 16, as * 16);
+
+						if (angle) {
+							QLineF ln(pos, QPointF(pos.x() + rect.width(),
+							  pos.y()));
+							ln.setAngle(a1);
+							painter->setPen(QPen(Qt::black, 1, Qt::DashLine));
+							painter->drawLine(ln);
+							ln.setAngle(a2);
+							painter->drawLine(ln);
+						}
 					}
 				}
-			}
-		} else {
-			QRect rect(lightRect(pos, p->lights.range));
+			} else if (l.color() && l.range() >= MAJOR_RANGE) {
+				Sector s(l.color(), 0, 3600);
+				if (rangeMap.value(s) >= l.range())
+					continue;
+				else
+					rangeMap.insert(s, l.range());
 
-			painter->setPen(QPen(Qt::black, 6, Qt::SolidLine, Qt::FlatCap));
-			painter->drawArc(rect, 0, 360 * 16);
-			painter->setPen(QPen(Style::color(p->lights.color), 4,
-			  Qt::SolidLine, Qt::FlatCap));
-			painter->drawArc(rect, 0, 360 * 16);
+				QRect rect(lightRect(pos, l.range()));
+				painter->setPen(QPen(Qt::black, 6, Qt::SolidLine, Qt::FlatCap));
+				painter->drawArc(rect, 0, 360 * 16);
+				painter->setPen(QPen(Style::color(l.color()), 4, Qt::SolidLine,
+				  Qt::FlatCap));
+				painter->drawArc(rect, 0, 360 * 16);
+			}
 		}
 	}
 }
 
-static void removeDuplicitLabel(QList<TextItem *> &labels, const QString &text,
+static void removeDuplicitLabel(QList<TextItem*> &labels, const QString &text,
   const QRectF &tileRect)
 {
 	for (int i = 0; i < labels.size(); i++) {
@@ -456,8 +475,47 @@ void RasterTile::processShields(const QList<MapData::Poly> &lines,
 	}
 }
 
+static bool sectorLight(const QVector<Light> &lights)
+{
+	for (int i = 0; i < lights.size(); i++) {
+		const Light &l = lights.at(i);
+		if (l.color() && l.range() >= MAJOR_RANGE)
+			return true;
+		for (int j = 0; j < l.sectors().size(); j++) {
+			const Light::Sector &start = l.sectors().at(j);
+			const Light::Sector &end = (j == l.sectors().size() - 1)
+			  ? l.sectors().at(0) : l.sectors().at(j+1);
+			quint32 angle = end.angle() - start.angle();
+			if (start.color() && (angle || start.range() >= MAJOR_RANGE))
+				return true;
+		}
+	}
+
+	return false;
+}
+
+static Light::Color ordinaryLight(const QVector<Light> &lights)
+{
+	for (int i = 0; i < lights.size(); i++) {
+		const Light &l = lights.at(i);
+		if (l.color() && l.range() < MAJOR_RANGE)
+			return l.color();
+		for (int j = 0; j < l.sectors().size(); j++) {
+			const Light::Sector &start = l.sectors().at(j);
+			const Light::Sector &end = (j == l.sectors().size() - 1)
+			  ? l.sectors().at(0) : l.sectors().at(j+1);
+			quint32 angle = end.angle() - start.angle();
+			if (start.color() && !angle && start.range() < MAJOR_RANGE)
+				return start.color();
+		}
+	}
+
+	return Light::None;
+}
+
 void RasterTile::processPoints(QList<MapData::Point> &points,
-  QList<TextItem*> &textItems, QList<const MapData::Point*> &lights)
+  QList<TextItem*> &textItems, QList<TextItem*> &lights,
+  QList<const MapData::Point*> &sectorLights)
 {
 	std::sort(points.begin(), points.end());
 
@@ -466,9 +524,10 @@ void RasterTile::processPoints(QList<MapData::Point> &points,
 		const Style *style = _data->style();
 		const Style::Point &ps = style->point(point.type);
 		bool poi = Style::isPOI(point.type);
+		bool sl = sectorLight(point.lights);
 
-		if (point.lights.isSectorLight())
-			lights.append(&point);
+		if (sl)
+			sectorLights.append(&point);
 
 		const QString *label = point.label.text().isEmpty()
 		  ? 0 : &(point.label.text());
@@ -490,15 +549,17 @@ void RasterTile::processPoints(QList<MapData::Point> &points,
 
 		TextPointItem *item = new TextPointItem(pos + offset, label, fnt, img,
 		  color, hcolor, 0, ICON_PADDING);
-		if (item->isValid() && (point.lights.isSectorLight()
-		  || !item->collides(textItems))) {
+		if (item->isValid() && (sl || !item->collides(textItems))) {
 			textItems.append(item);
-			if (point.lights.color && !point.lights.isSectorLight())
-				textItems.append(new TextPointItem(pos + style->lightOffset(),
-				  0, 0, style->light(point.lights.color), 0, 0, 0, 0));
+			Light::Color color = ordinaryLight(point.lights);
+			if (color)
+				lights.append(new TextPointItem(pos + style->lightOffset(),
+				  0, 0, style->light(color), 0, 0, 0, 0));
 		} else
 			delete item;
 	}
+
+
 }
 
 void RasterTile::fetchData(QList<MapData::Poly> &polygons,
@@ -583,8 +644,8 @@ void RasterTile::render()
 	QList<MapData::Poly> polygons;
 	QList<MapData::Poly> lines;
 	QList<MapData::Point> points;
-	QList<TextItem*> textItems;
-	QList<const MapData::Point*> lights;
+	QList<TextItem*> textItems, lights;
+	QList<const MapData::Point*> sectorLights;
 	QImage arrows[2];
 
 	arrows[ROAD] = Util::svg2img(":/symbols/oneway.svg", _ratio);
@@ -595,7 +656,7 @@ void RasterTile::render()
 	ll2xy(lines);
 	ll2xy(points);
 
-	processPoints(points, textItems, lights);
+	processPoints(points, textItems, lights, sectorLights);
 	processPolygons(polygons, textItems);
 	processLines(lines, textItems, arrows);
 
@@ -610,9 +671,11 @@ void RasterTile::render()
 	drawPolygons(&painter, polygons);
 	drawHillShading(&painter);
 	drawLines(&painter, lines);
-	drawSectorLights(&painter, lights);
+	drawTextItems(&painter, lights);
+	drawSectorLights(&painter, sectorLights);
 	drawTextItems(&painter, textItems);
 
+	qDeleteAll(lights);
 	qDeleteAll(textItems);
 
 	//painter.setPen(Qt::red);
